@@ -1,4 +1,6 @@
+import datetime
 import json
+import math
 import mimetypes
 import os
 import requests
@@ -107,33 +109,50 @@ class PushBullet(_PushBullet):
     def __repr__(self):
         return '<PushBullet [{}]>'.format(self.api_key)
 
-    def devices(self):
+    def devices(self, only_active=True):
         r = self._s.get(self.DEVICES_URL)
         _pushbullet_responses(r)
-        return [Device(device, self.api_key) for device in r.json()['devices'] if device['active'] is not False]
+        if only_active:
+            return [Device(device, self.api_key) for device in r.json()['devices'] if device['active'] is not False]
+        else:
+            return [Device(device, self.api_key) for device in r.json()['devices']]
 
-    def contacts(self):
+    def contacts(self, only_active=True):
         r = self._s.get(self.CONTACTS_URL)
         _pushbullet_responses(r)
-        return [Contact(contact, self.api_key) for contact in r.json()['contacts'] if contact['active'] is not False]
+        if only_active:
+            return [Contact(contact, self.api_key) for contact in r.json()['contacts'] if contact['active'] is not False]
+        else:
+            return [Contact(contact, self.api_key) for contact in r.json()['contacts']]
+
+    def create_device(self, nickname, device_type='stream'):
+        data = {'type': device_type,
+                'nickname': nickname}
+        r = self._s.post(self.DEVICES_URL, data=json.dumps(data))
+        _pushbullet_responses(r)
+        return Device(r.json(), self.api_key)
 
 
 class Device(_PushBullet):
-    def __init__(self, device, api_key=None):
+    def __init__(self, device, api_key):
         self.iden = device['iden']
-        self.model = device['model']
-        self.pushable = device['pushable']
+        self.type = device.get('type', 'inactive')
+        self.created = datetime.date.fromtimestamp(math.floor(device['created']))
+        self.modified = datetime.date.fromtimestamp(math.floor(device['modified']))
+        self.active = device['active']
+        self.pushable = device.get('pushable', False)
+        self.json = device
         super(Device, self).__init__(api_key)
 
     def __repr__(self):
-        return '<Device [{} - {}]>'.format(self.model, self.iden)
+        return '<Device [{} - {}]>'.format(self.type, self.iden)
 
     def delete(self):
         return _pushbullet_responses(self._s.delete('{}/{}'.format(self.DEVICES_URL, self.iden)))
 
 
 class Contact(_PushBullet):
-    def __init__(self, contact, api_key=None):
+    def __init__(self, contact, api_key):
         self.iden = contact['iden']
         self.email = contact['email']
         self.name = contact['name']
